@@ -1,7 +1,7 @@
 package Math::Random::Secure::RNG;
-BEGIN {
-  $Math::Random::Secure::RNG::VERSION = '0.06';
-}
+$Math::Random::Secure::RNG::VERSION = '0.08';
+# ABSTRACT: The underlying PRNG, as an object.
+
 use Moo;
 use Math::Random::ISAAC;
 use Crypt::Random::Source::Factory;
@@ -130,11 +130,11 @@ __END__
 
 =head1 NAME
 
-Math::Random::Secure::RNG
+Math::Random::Secure::RNG - The underlying PRNG, as an object.
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -154,10 +154,6 @@ to a random-number generator, you can use this.
 Math::Random::Secure::RNG uses L<Any::Moose>, meaning that it has a
 C<new> method that works like L<Mouse> or L<Moose> modules work.
 
-=head1 NAME
-
-Math::Random::Secure::RNG - The underlying PRNG, as an object.
-
 =head1 METHODS
 
 =head2 irand
